
Changelog
=========


0.0.3 (2020-03-31)
------------------

* Ensured that ErrorMsg always has length, even if corresponding Exception message is empty
* Removed dir_exists() and file_exists() functions that raise exceptions

0.0.2 (2020-03-30)
------------------

* Introduced ResultTuple type for error handling without exceptions

0.0.0 (2020-03-20)
------------------

* First release on PyPI.
